import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-classic/TickXsWhiteIcon';
import IndeterminateIcon from '@alfalab/icons-classic/CheckIndeterminateSWhiteIcon';

var styles = {"component":"checkbox__component_qglpo","start":"checkbox__start_qglpo","center":"checkbox__center_qglpo","addons":"checkbox__addons_qglpo","block":"checkbox__block_qglpo","box":"checkbox__box_qglpo","m":"checkbox__m_qglpo","disabled":"checkbox__disabled_qglpo","checked":"checkbox__checked_qglpo","indeterminate":"checkbox__indeterminate_qglpo","focused":"checkbox__focused_qglpo","content":"checkbox__content_qglpo","label":"checkbox__label_qglpo","hint":"checkbox__hint_qglpo","indeterminateIcon":"checkbox__indeterminateIcon_qglpo"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', align = 'start', addons, block, onChange, className, name, disabled, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, null),
            indeterminate && !checked && (React.createElement(IndeterminateIcon, { className: styles.indeterminateIcon }))),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
